# Exhaustive Search with Bayesian Model Averaging (ExhBMA)

# Installation
```
pip install exhbma
```

# Documentation
User documentation is available [here](https://exhbma.readthedocs.io).
You can try sample notebooks in [tutorials](/tutorials) directory.

# Reference paper
In preparing.
